@@ -1448,7 +1448,7 @@ BmExpandLoadFile (
       "%a:%a: failed to allocate reserved pages: "
       "BufferSize=%Lu LoadFile=\"%s\" FilePath=\"%s\"\n",
       gEfiCallerBaseName,
-      __FUNCTION__,
+      __func__,
       (UINT64)BufferSize,
       LoadFileText,
       FileText
@@ -2218,6 +2218,15 @@ BmEnumerateBootOptions (
         continue;
       }
 
+      //
+      // Skip removable media if not present
+      //
+      if ((BlkIo->Media->RemovableMedia == TRUE) &&
+          (BlkIo->Media->MediaPresent == FALSE))
+      {
+        continue;
+      }
+
       Description = BmGetBootDescription (Handles[Index]);
       BootOptions = ReallocatePool (
                       sizeof (EFI_BOOT_MANAGER_LOAD_OPTION) * (*BootOptionCount),
